Module: EagerEye::Detectors::Concerns::ClassInspector
- Included in:
- DecoratorNPlusOne, SerializerNesting
- Defined in:
- lib/eager_eye/detectors/concerns/class_inspector.rb
Constant Summary collapse
- HAS_MANY_ASSOCIATIONS =
%w[ authors users owners creators admins members customers clients posts articles comments categories tags children companies organizations projects tasks items orders products accounts profiles settings images avatars photos attachments documents ].freeze
- ACTIVE_STORAGE_METHODS =
%i[ attached? attach attachment attachments blob blobs purge purge_later variant preview ].freeze